#
# spec file for package python-cmdln
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-cmdln
Version:        2.0.0
Release:        3.18
Summary:        An improved cmd.py for Writing Multi-command Scripts and Shells
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/trentm/cmdln
Source:         https://files.pythonhosted.org/packages/source/c/cmdln/cmdln-%{version}.zip
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRequires:  tcl
BuildRequires:  unzip
BuildArch:      noarch
%python_subpackages

%description
`cmdln.py` is an extension of Python's default `cmd.py` module that
provides "a simple framework for writing line-oriented command
interpreters".	The idea (with both cmd.py and cmdln.py) is to be able
to quickly build multi-sub-command tools (think cvs or svn) and/or
simple interactive shells (think gdb or pdb).  Cmdln's extensions make
it more natural to write sub-commands, integrate optparse for simple
option processing, and make having good command documentation easier.

%prep
%setup -q -n cmdln-%{version}
# remove unwanted shebang
sed -i '/^#!/d' lib/cmdln.py
# remove executable bit in documentation
chmod -x examples/*

%build
%python_build

%install
%python_install

%check

%files %{python_files}
%doc LICENSE.txt docs/ examples/
%{python_sitelib}/cmdln*
%pycache_only %{python_sitelib}/__pycache__/*

%changelog
* Fri Oct 23 2020 Matej Cepl <mcepl@suse.com>
- Use %%pycache_only %%python_sitelib instead of %%python3_sitelib
  fixes gh#openSUSE/python-rpm-macros#64#issuecomment-715373348
* Thu Sep  7 2017 mimi.vx@gmail.com
- convert to singlespec package
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 2.0.0:
  * Added support for Python 3 (test suite fully passing)
- additional changes from version 1.3.1:
  * Allow dynamic setting of `self.prompt` and have it update
- additional changes from version 1.3.0:
  * Change `self.postoptparse()` hook handling to use the retval
    value. If it is none-zero (or non-None), then `Cmdln.main()`
    processing exits
  * Fix tab-completion on Mac with Python builds that build against
    editline where `readline.parse_and_bind` have different syntax
- additional changes from version 1.2.0:
  * Issue 3: Raise upper bound width for left column in "Commands"
    and "help topics" lists in help output to 30. Also fix buglet
    in that column formatting.
  * Issue 7: add `man_sections_from_cmdln(...)` for generating
    decent man page content automatically from a `Cmdln` subclass
    instance. See ManPageGeneration for an overview.
- additional changes from version 1.1.3:
  * Stop using `string.whitespace` because it can be an 8-bit
    string with non-ASCII chars in it, leading to potential
    `UnicodeDecodeError`s. See Komodo Bug 81316.
- update project URL
- add tcl as BuildRequires for the tests
- remove unwanted shebang from cmdln.py
- remove executable bit of examples in documentation
- run the tests during package build
- remove README.txt from package, not provided anymore
* Thu Oct 24 2013 speilicke@suse.com
- Update to version 1.1.2:
  + No changelog
- Spec file cleanup
* Fri Aug 28 2009 coolo@novell.com
- merge build service with factory
* Mon Jun  9 2008 poeml@suse.de
- don't make the "Release" tag a macro
* Thu May  1 2008 poeml@suse.de
- This package is not a noarch package -- fix the build.
* Thu Mar  6 2008 toms@suse.de
- Initial package 1.1.1
